
# Type: prefixes


prefix / URI definitions to be added to the context beyond those fetched from prefixcommons in id prefixes

URI: [meta:prefixes](https://w3id.org/biolink/biolinkml/meta/prefixes)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>0..*</sub> [Prefix](Prefix.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
